\name{ACC_bootstrap}
\alias{ACC_bootstrap}
\title{
  Computes Anomaly Correlation Coefficient (Spatial Correlation)
}
\description{
  Matrix var_exp & var_obs should have dimensions (nexp/nobs,  nsdates,  
  nltimes,  nlat,  nlon).
  ACC computes the Anomaly Correlation Coefficient for each jexp in 
  1:nexp and each jobs in 1:nobs which gives nexp x nobs ACC for each 
  startdate and each leadtime.
  A domain can be selected by providing the list of longitudes/latitudes
  (lon/lat) of the grid together with the corner of the domain:
  lonlatbox = c(lonmin,  lonmax,  latmin,  latmax)
}

\usage{
  ACC_bootstrap(var_exp, var_obs, lon = NULL, lat = NULL,
                         lonlatbox = NULL,nrand=2000,
                         blocklen=1, method="quantile")
} 
\arguments{
  \item{var_exp}{
    Matrix of experimental data with dimensions: 
    c(nexp, nsdates, nltimes, nlat, nlon)
  }
  \item{var_obs}{
    Matrix of observational data with the same dimensions as var_exp except 
    along the first dimension:
    c(nobs, nsdates, nltimes, nlat, nlon)
  }
  \item{lon}{
    Array of longitudes of the var_exp/var_obs grids, optional.
  }
  \item{lat}{
    Array of latitudes of the var_exp/var_obs grids, optional.
  }
  \item{lonlatbox}{
    Domain to select : c(lonmin, lonmax, latmin, latmax), optional.
  }
  \item{nrand}{
    number of sample for the bootstrap  (default: 2000).
  }
  \item{blocklen}{
    Size of the block used for re-sampling the field, (default 1).
  }
   \item{method}{
     method used to calculate the confidence interval, (default quantile).
  }
  
}
\value{
  \item{ACC}{
    Matrix with c(nexp,  nobs,  nsdates,  nleadtimes,  4) dimensions.
    The fourth dimension of length 4 corresponds to the lower limit of
    the 95\% confidence interval,  the computed ACC,  the upper limit of 
    the 95\% confidence interval and the p-value. 
    The lower/upper limit of 95\% interval and the p-values are estimated
    with the bootstrap sampling based on Mason and Mimmack (1991)
    if method "mason" set or,  in the default case ("quantile"),
    simply the 2.5\% and the 97.5\% of the bootstrap distribution.
    With the bootstrap technique,  it is not mandatory that
    the real correlation is included in the confidence interval.
    The significance of the ACC can be estimated with to different ways:
    p-value<0.05 or a confidence interval which does not include the 0.
  }
  \item{MACC}{
    Matrix with c(nexp,  nobs,  nsdates,  nleadtimes,  4) dimensions.
    The fourth dimension of length 4 corresponds to the lower limit of
    the 95\% confidence interval,  the computed Mean Anomaly Correlation
    Coefficient, the upper limit of  the 95\% confidence interval
    and the p-value. 
    The lower/upper limit of 95\% interval and the p-values are estimated
    with the bootstrap sampling based on Mason and Mimmack (1991)
    if method "mason" set or,  in the default ("quantile") case,
    simply the 2.5\% and the 97.5\% of the bootstrap distribution.
    With the bootstrap technique it is not mandatory that the real correlation
    is included in the confidence interval.
    The significance of the ACC can be estimated with to different ways:
    p-value<0.05 or a confidence interval which does not include the 0.
  }
}
\author{
  History:
  1.0 -  2014-05  (C. Prodhomme, \email{chloe.prodhomme@ic3.cat})  -  Original code
}
\keyword{datagen}
