\name{PlotVsLTime}
\alias{PlotVsLTime}
\title{
  Plots A Score Along The Forecast Time With Its Confidence Interval
}
\description{
  Plots The Correlation (\code{Corr()}) or the Root Mean Square Error 
  (\code{RMS()}) between the forecasted values and their observational 
  counterpart or the slopes of their trends (\code{Trend()}) or the 
  InterQuartile Range, Maximum-Mininum, Standard Deviation or Median 
  Absolute Deviation of the Ensemble Members (\code{Spread()}), or
  the ratio between the Ensemble Spread and the RMSE of the Ensemble 
  Mean (\code{RatioSDRMS()}) along the forecast time for all the input 
  experiments on the same figure with their confidence intervals.
}
\usage{
  PlotVsLTime(var, toptitle = "", ytitle = "", monini = 1, freq = 12, 
  nticks = NULL, limits = NULL, listexp = c("exp1", "exp2", "exp3"), 
  listobs = c("obs1", "obs2", "obs3"), biglab = F, hlines = NULL, leg = T, 
  siglev = F, fileout = "output_plotvsltime.eps", sizetit = 1, show_conf = T)
}
\arguments{
  \item{var}{
    Matrix containing any Prediction Score with dimensions:
         (nexp/nmod, 3/4 ,nltime)
      or (nexp/nmod, nobs, 3/4 ,nltime)
  }
  \item{toptitle}{
    Main title, optional.
  }
  \item{ytitle}{
    Title of Y-axis, optional.
  }
  \item{monini}{
    Starting month between 1 and 12. Default = 1.
  }
  \item{freq}{
    1 = yearly, 12 = monthly, 4 = seasonal, ... Default = 12.
  }
  \item{nticks}{
    Number of ticks and labels on the x-axis, optional.
  }
  \item{limits}{
    c(lower limit, upper limit): limits of the Y-axis, optional.
  }
  \item{listexp}{
    List of experiment names, optional.
  }
  \item{listobs}{
    List of observation names, optional.
  }
  \item{biglab}{
    T/F for presentation/paper plot. Default = F.
  }
  \item{hlines}{
    c(a,b, ..) Add horizontal black lines at Y-positions a,b, ...
    Default = NULL.
  }
  \item{leg}{
    T/F if legend should be added or not to the plot. Default = T.
  }
  \item{siglev}{
    T/F if significance level should replace confidence interval.
    Default = F.
  }
  \item{fileout}{
    Name of the output eps file.
  }
  \item{sizetit}{
    Multiplicative factor to change title size, optional.
  }
  \item{show_conf}{
    T/F to show/not confidence intervals for input variables.
  }
}
\details{
  Examples of input:


     Model and observed output from \code{Load()} then \code{Clim()} then
     \code{Ano()} then \code{Smoothing()}:
       (nmod, nmemb, nsdate, nltime) and (nobs, nmemb, nsdate, nltime)
     then averaged over the members 
       \code{Mean1Dim(var_exp/var_obs, posdim = 2)}:
       (nmod, nsdate, nltime) and (nobs, nsdate, nltime)
     then passed through 
       \code{Corr(exp, obs, posloop = 1, poscor = 2)} or 
       \code{RMS(exp, obs, posloop = 1, posRMS = 2)}:
       (nmod, nobs, 3, nltime)
     would plot the correlations or RMS between each exp & each obs as a
     function of the forecast time.
}
\author{
  History:
  0.1  -  2011-03  (V. Guemas,                           -  Original code
                 \email{virginie.guemas@ic3.cat})
  0.2  -  2013-03  (I. Andreu-Burillo,                   -  Introduced parameter
       -         \email{isabel.andreu-burillo@ic3.cat})  -  sizetit
  0.3  -  2013-10  (I. Andreu-Burillo,                   -  Introduced parameter
       -         \email{isabel.andreu-burillo@ic3.cat})  -  show_conf 
  1.0  -  2013-11  (N. Manubens,
                 \email{nicolau.manubens@ic3.cat})       -  Formatting to CRAN
}
\keyword{dynamic}
